@@ -848,18 +848,28 @@ def claw_free(G: GraphLike) -> bool:
     Examples
     --------
     >>> import graphcalc as gc
-    >>> from graphcalc.generators import path_graph
+    >>> from graphcalc.generators import path_graph, star_graph
 
     >>> G = path_graph(4)
     >>> gc.claw_free(G)
     True
+
+    >>> H = star_graph(6)
+    >>> gc.claw_free(H)
+    False
     """
-    claw = nx.star_graph(3)
-    for S in set(itertools.combinations(G.nodes(), 3)):
-        H = G.subgraph(list(S))
-        if nx.is_isomorphic(H, claw):
-            return False
-    # if the above loop completes, the graph is claw-free
+    for v in G:
+        N = list(G.neighbors(v))
+        if len(N) < 3:
+            continue
+        # Early reject if there exist a,b,c in N with no edges among them
+        # (i.e., independent triple in G[N])
+        GN = G.subgraph(N)
+        # Quick pruning: if there are too few edges, an independent triple must exist
+        # but we’ll just check triples directly (usually small neighborhoods).
+        for a, b, c in itertools.combinations(N, 3):
+            if not GN.has_edge(a, b) and not GN.has_edge(a, c) and not GN.has_edge(b, c):
+                return False
     return True
 
 def connected_and_claw_free(G: GraphLike) -> bool:
@@ -906,17 +916,33 @@ def K_4_free(G: GraphLike) -> bool:
     Examples
     --------
     >>> import graphcalc as gc
-    >>> from graphcalc.generators import complete_graph
+    >>> from graphcalc.generators import complete_graph, star_graph
 
     >>> G = complete_graph(4)
     >>> gc.K_4_free(G)
     False
+
+    >>> H = star_graph(6)
+    >>> gc.triangle_free(H)
+    True
     """
-    K_4 = nx.complete_graph(4)
-    for S in set(itertools.combinations(G.nodes(), 4)):
-        H = G.subgraph(list(S))
-        if nx.is_isomorphic(H, K_4):
-            return False
+    for v in G:
+        N = list(G.neighbors(v))
+        if len(N) < 3:
+            continue
+        H = G.subgraph(N)  # induced by neighbors of v
+        # Does H contain a triangle?
+        # Fast check: for each u in H, see if its neighbors within H have an edge among them.
+        # (equivalently, any two neighbors of u in H that are adjacent -> triangle)
+        adj = {u: set(H.neighbors(u)) for u in H}
+        for u in H:
+            # check if adj[u] contains an edge: i.e., any w,z in adj[u] with w in adj[z]
+            Au = list(adj[u])
+            for i in range(len(Au)):
+                w = Au[i]
+                # intersect once to avoid O(d^2) worst loops when small
+                if adj[u] & adj[w]:
+                    return False
     return True
 
 def connected_and_K_4_free(G: GraphLike) -> bool:
@@ -964,21 +990,25 @@ def triangle_free(G: GraphLike) -> bool:
     Examples
     --------
     >>> import graphcalc as gp
-    >>> from graphcalc.generators import complete_graph
+    >>> from graphcalc.generators import complete_graph, star_graph
 
     >>> G = complete_graph(4)
     >>> gc.triangle_free(G)
     False
-    """
-    # define a triangle graph, also known as the complete graph K_3
-    triangle = nx.complete_graph(3)
 
-    # enumerate over all possible combinations of 3 vertices contained in G
-    for S in set(itertools.combinations(G.nodes(), 3)):
-        H = G.subgraph(list(S))
-        if nx.is_isomorphic(H, triangle):
-            return False
-    # if the above loop completes, the graph is triangle free
+    >>> H = star_graph(6)
+    >>> gc.triangle_free(H)
+    True
+    """
+    adj = {u: set(G.neighbors(u)) for u in G}
+    deg = {u: len(adj[u]) for u in G}
+
+    for u in G:
+        Nu_forward = {v for v in adj[u] if (deg[u] < deg[v]) or (deg[u] == deg[v] and u < v)}
+        for v in Nu_forward:
+            # Intersect only with v's forward neighbors to keep sets small
+            if Nu_forward & ({w for w in adj[v] if (deg[v] < deg[w]) or (deg[v] == deg[w] and v < w)}):
+                return False
     return True
 
 def connected_and_triangle_free(G: GraphLike) -> bool:
@@ -1117,15 +1147,15 @@ def cograph(G: GraphLike) -> bool:
     >>> import graphcalc as gc
     >>> from graphcalc.generators import path_graph, complete_graph, cycle_graph
 
-    # P4 is not a cograph
+    >>> # P4 is not a cograph
     >>> gc.cograph(path_graph(4))
     False
 
-    # Complete graphs are cographs
+    >>> # Complete graphs are cographs
     >>> gc.cograph(complete_graph(5))
     True
 
-    # C4 is P4-free, hence a cograph
+    >>> # C4 is P4-free, hence a cograph
     >>> gc.cograph(cycle_graph(4))
     True
     """
@@ -1184,15 +1214,15 @@ def connected_and_cograph(G: GraphLike) -> bool:
     >>> import graphcalc as gc
     >>> from graphcalc.generators import path_graph, complete_graph, cycle_graph
 
-    # P4 is not a cograph
+    >>> # P4 is not a cograph
     >>> gc.connected_and_cograph(path_graph(4))
     False
 
-    # Complete graphs are cographs
+    >>> # Complete graphs are cographs
     >>> gc.connected_and_cograph(complete_graph(5))
     True
 
-    # C4 is P4-free, hence a cograph
+    >>> # C4 is P4-free, hence a cograph
     >>> gc.connected_and_cograph(cycle_graph(4))
     True
     """
