@@ -1,7 +1,10 @@
 
 from typing import Hashable, List
+from typing import Iterable, List, Sequence, Tuple
+
 import networkx as nx
 import graphcalc as gc
+from graphcalc import SimpleGraph
 from graphcalc.utils import enforce_type, GraphLike
 
 
@@ -15,11 +18,14 @@ __all__= [
     "slater",
     "sub_total_domination_number",
     "annihilation_number",
+    "residue_from_degrees",
+    "k_residue_from_degrees",
     "residue",
+    "k_residue",
     "harmonic_index",
 ]
 
-@enforce_type(0, (nx.Graph, gc.SimpleGraph))
+@enforce_type(0, (nx.Graph, SimpleGraph))
 def degree(G: GraphLike, v: Hashable) -> int:
     r"""
     Returns the degree of a vertex in a graph.
@@ -50,7 +56,7 @@ def degree(G: GraphLike, v: Hashable) -> int:
     """
     return G.degree(v)
 
-@enforce_type(0, (nx.Graph, gc.SimpleGraph))
+@enforce_type(0, (nx.Graph, SimpleGraph))
 def degree_sequence(G: GraphLike, nonincreasing=True) -> List[int]:
     r"""
     Returns the degree sequence of a graph.
@@ -87,7 +93,7 @@ def degree_sequence(G: GraphLike, nonincreasing=True) -> List[int]:
         degrees.sort()
     return degrees
 
-@enforce_type(0, (nx.Graph, gc.SimpleGraph))
+@enforce_type(0, (nx.Graph, SimpleGraph))
 def average_degree(G: GraphLike) -> float:
     r"""
     Returns the average degree of a graph.
@@ -116,7 +122,7 @@ def average_degree(G: GraphLike) -> float:
     degrees = degree_sequence(G)
     return sum(degrees) / len(degrees)
 
-@enforce_type(0, (nx.Graph, gc.SimpleGraph))
+@enforce_type(0, (nx.Graph, SimpleGraph))
 def maximum_degree(G: GraphLike) -> int:
     r"""
     Returns the maximum degree of a graph.
@@ -144,7 +150,7 @@ def maximum_degree(G: GraphLike) -> int:
     degrees = degree_sequence(G)
     return max(degrees)
 
-@enforce_type(0, (nx.Graph, gc.SimpleGraph))
+@enforce_type(0, (nx.Graph, SimpleGraph))
 def minimum_degree(G: GraphLike) -> int:
     r"""
     Returns the minimum degree of a graph.
@@ -172,12 +178,12 @@ def minimum_degree(G: GraphLike) -> int:
     degrees = degree_sequence(G)
     return min(degrees)
 
-@enforce_type(0, (nx.Graph, gc.SimpleGraph))
+@enforce_type(0, (nx.Graph, SimpleGraph))
 def sub_k_domination_number(G: GraphLike, k: int) -> float:
     r"""Return the sub-k-domination number of the graph.
 
-    The *sub-k-domination number* of a graph G with *n* nodes is defined as the
-    smallest positive integer t such that the following relation holds:
+    The *sub-k-domination number* of a graph :math:`G` with *n* nodes is defined as the
+    smallest positive integer :math:`t` such that the following relation holds:
 
     .. math::
         t + \frac{1}{k}\sum_{i=0}^t d_i \geq n
@@ -235,12 +241,12 @@ def sub_k_domination_number(G: GraphLike, k: int) -> float:
     # if above loop completes, return None
     return None
 
-@enforce_type(0, (nx.Graph, gc.SimpleGraph))
+@enforce_type(0, (nx.Graph, SimpleGraph))
 def slater(G: GraphLike) -> int:
     r"""
     Returns the Slater invariant for the graph.
 
-    The Slater invariant of a graph G is a lower bound for the domination
+    The Slater invariant of a graph :math:`G` is a lower bound for the domination
     number of a graph defined by:
 
     .. math::
@@ -252,10 +258,10 @@ def slater(G: GraphLike) -> int:
         {d_1 \geq d_2 \geq \cdots \geq d_n}
 
     is the degree sequence of the graph ordered in non-increasing order and *n*
-    is the order of G.
+    is the order of :math:`G`.
 
     Amos et al. rediscovered this invariant and generalized it into what is
-    now known as the sub-*k*-domination number.
+    now known as the sub-:math:`k`-domination number.
 
     Parameters
     ----------
@@ -290,8 +296,8 @@ def slater(G: GraphLike) -> int:
 
     References
     ----------
-    D. Amos, J. Asplund, B. Brimkov, and R. Davila, The sub-k-domination number
-    of a graph with applications to k-domination, *arXiv preprint
+    D. Amos, J. Asplund, B. Brimkov, and R. Davila, The sub-:math:`k`-domination number
+    of a graph with applications to :math:`k`-domination, *arXiv preprint
     arXiv:1611.02379*, (2016)
 
     P.J. Slater, Locating dominating sets and locating-dominating set, *Graph
@@ -301,7 +307,7 @@ def slater(G: GraphLike) -> int:
     """
     return sub_k_domination_number(G, 1)
 
-@enforce_type(0, (nx.Graph, gc.SimpleGraph))
+@enforce_type(0, (nx.Graph, SimpleGraph))
 def sub_total_domination_number(G: GraphLike) -> int:
     r"""
     Returns the sub-total domination number of the graph.
@@ -362,12 +368,12 @@ def sub_total_domination_number(G: GraphLike) -> int:
     # if above loop completes, return None
     return None
 
-@enforce_type(0, (nx.Graph, gc.SimpleGraph))
+@enforce_type(0, (nx.Graph, SimpleGraph))
 def annihilation_number(G: GraphLike) -> int:
     r"""
     Returns the annihilation number of the graph.
 
-    The annihilation number of a graph *G* is defined as:
+    The annihilation number of a graph :math:`G` is defined as:
 
     .. math::
         a(G) = \max\{t : \sum_{i=1}^t d_i \leq m \}
@@ -378,7 +384,7 @@ def annihilation_number(G: GraphLike) -> int:
         d_1 \leq d_2 \leq \cdots \leq d_n
 
     is the degree sequence of the graph ordered in non-decreasing order, and
-    *m* is the number of edges in *G*.
+    :math:`m` is the number of edges in :math:`G`.
 
     Parameters
     ----------
@@ -422,7 +428,134 @@ def annihilation_number(G: GraphLike) -> int:
         if sum(D[:i]) <= m:
             return i
 
-@enforce_type(0, (nx.Graph, gc.SimpleGraph))
+
+# If you have these in your package:
+# from .simplegraph import SimpleGraph
+# from .typing import GraphLike
+# from .decorators import enforce_type
+# import graphcalc as gc
+ # replace with your union (nx.Graph | SimpleGraph)
+
+# ──────────────────────────────────────────────────────────────────────────────
+# Core: elimination sequence from a degree list
+# ──────────────────────────────────────────────────────────────────────────────
+
+def elimination_sequence_from_degrees(degrees: Sequence[int]) -> List[int]:
+    """
+    Compute the Havel–Hakimi elimination sequence E(D) from a degree sequence.
+
+    The elimination sequence records *every* removed entry (including trailing 0's)
+    as the HH process proceeds on a copy of the degree list.
+
+    Parameters
+    ----------
+    degrees : Sequence[int]
+        Nonnegative integer degree sequence (assumed graphical when coming from a graph).
+
+    Returns
+    -------
+    List[int]
+        The elimination sequence E(D), i.e., the list of popped values at each HH step.
+
+    Notes
+    -----
+    - For a genuine graph degree sequence, no negativity or length violations occur.
+    - We sort in non-increasing order at each step (standard HH).
+    """
+    seq = list(degrees)
+    if not seq:
+        return []
+
+    # Ensure non-increasing
+    seq.sort(reverse=True)
+    E: List[int] = []
+
+    while seq:
+        d = seq.pop(0)
+        E.append(d)
+
+        if d < 0:
+            raise ValueError("Negative entry encountered during Havel–Hakimi.")
+        if d > len(seq):
+            # This would signal non-graphical input if not from a graph.
+            raise ValueError("Degree too large for remaining sequence in Havel–Hakimi.")
+
+        # Decrement next d entries
+        for i in range(d):
+            seq[i] -= 1
+
+        # Keep sorted for next iteration
+        seq.sort(reverse=True)
+
+    return E
+
+
+# ──────────────────────────────────────────────────────────────────────────────
+# k-residue from degrees
+# ──────────────────────────────────────────────────────────────────────────────
+
+def k_residue_from_degrees(degrees: Sequence[int], k: int) -> int:
+    """
+    Compute the k-residue R_k from a degree sequence via its elimination sequence.
+
+    Definition
+    ----------
+    For elimination sequence E = E(D) and k >= 1,
+        R_k(E) = sum_{i=0}^{k-1} (k - i) * f_i(E),
+    where f_i(E) is the frequency of i in E.
+
+    Parameters
+    ----------
+    degrees : Sequence[int]
+        Nonnegative integer degree sequence (assumed graphical when from a graph).
+    k : int
+        Parameter k >= 1.
+
+    Returns
+    -------
+    int
+        The k-residue R_k(D).
+
+    See Also
+    --------
+    elimination_sequence_from_degrees
+    """
+    if k < 1:
+        raise ValueError("k must be an integer >= 1.")
+
+    E = elimination_sequence_from_degrees(degrees)
+    # Count only 0..k-1
+    freq = [0] * k
+    for x in E:
+        if 0 <= x < k:
+            freq[x] += 1
+    return int(sum((k - i) * freq[i] for i in range(k)))
+
+
+# ──────────────────────────────────────────────────────────────────────────────
+# Graph wrappers that reuse the degree-sequence core
+# ──────────────────────────────────────────────────────────────────────────────
+
+# Optional: a degree-sequence version of your classical residue for symmetry
+def residue_from_degrees(degrees: Sequence[int]) -> int:
+    """
+    Classical residue R(D): number of zeros in the elimination sequence E(D).
+
+    Parameters
+    ----------
+    degrees : Sequence[int]
+        Degree sequence.
+
+    Returns
+    -------
+    int
+        R(D) = f_0(E(D)).
+    """
+    E = elimination_sequence_from_degrees(degrees)
+    return E.count(0)
+
+
+@enforce_type(0, (nx.Graph, SimpleGraph))
 def residue(G: GraphLike) -> int:
     r"""
     Returns the residue of a graph.
@@ -434,8 +567,8 @@ def residue(G: GraphLike) -> int:
 
     **Havel-Hakimi Algorithm**:
     - Sort the degree sequence in non-increasing order.
-    - Remove the largest degree (say, `d`) from the sequence.
-    - Reduce the next `d` degrees by 1.
+    - Remove the largest degree (say, :math:`d`) from the sequence.
+    - Reduce the next :math:`d` degrees by 1.
     - Repeat until all degrees are zero (graphical) or a negative degree is encountered (non-graphical).
 
     The residue is the count of zeros in the sequence when the algorithm terminates.
@@ -488,7 +621,55 @@ def residue(G: GraphLike) -> int:
 
     return len(degrees)
 
-@enforce_type(0, (nx.Graph, gc.SimpleGraph))
+@enforce_type(0, (nx.Graph, SimpleGraph))
+@enforce_type(1, int)
+def k_residue(G: GraphLike, k: int) -> int:
+    r"""
+    Compute the k-residue R_k(G) from the Havel–Hakimi elimination sequence.
+
+    Definition (Jelen generalizing Favaron–Mahéo–Saclé, Griggs–Kleitman, Triesch)
+    ---------------------------------------------------------------------------
+    Let D be a graphic degree sequence and E = E(D) its Havel–Hakimi elimination
+    sequence (the list of values removed at each step, including trailing zeros).
+    For k ≥ 1,
+        R_k(E) = sum_{i=0}^{k-1} (k - i) * f_i(E),
+    where f_i(E) is the frequency of i in E. Since E is determined by D(G), we
+    write R_k(G).
+
+    Special case: k = 1 gives R_1(G) = f_0(E) = R(G) (the usual residue).
+
+    Parameters
+    ----------
+    G : nx.Graph or SimpleGraph
+        Input graph.
+    k : int
+        Parameter k ≥ 1.
+
+    Returns
+    -------
+    int
+        The k-residue R_k(G).
+
+    Notes
+    -----
+    We explicitly build the elimination sequence E by performing the Havel–Hakimi
+    process and recording the removed value at each step, including zeros at the
+    end. This ensures f_0(E) equals the classical residue.
+
+    Examples
+    --------
+    >>> from graphcalc.generators import path_graph, complete_graph
+    >>> G = path_graph(4)
+    >>> k_residue(G, 1) == residue(G)  # should match your residue()
+    True
+    >>> H = complete_graph(4)
+    >>> k_residue(H, 2)  # weighted count of 0s and 1s in E(H)
+    3
+    """
+    degrees = gc.degree_sequence(G)  # or list(dict(G.degree()).values())
+    return k_residue_from_degrees(degrees, k)
+
+@enforce_type(0, (nx.Graph, SimpleGraph))
 def harmonic_index(G: GraphLike) -> float:
     r"""
     Returns the harmonic index of a graph.
